@@ -11,9 +11,7 @@ run()
   fi
 }
 
-. /vagrant/env.sh
-
-run sudo sed -i'' -e 's/httpredir/ftp.jp/g' /etc/apt/sources.list
+. /vagrant/tmp/env.sh
 
 run sudo apt-get update
 run sudo apt-get install -y lsb-release
